/* 
 * 
 * Home Health Grouper Software
 * 
 * Center for Medicare and Medicaid Services (CMS)
 * 
 * All code is provided as is.
 * 
 */
package gov.cms.hh.grouper.utility;

import static gov.cms.hh.data.meta.MetaData.FORMAT_DATE;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Enumeration;
import java.util.List;
import java.util.Properties;
import java.util.StringJoiner;
import java.util.logging.Level;
import java.util.logging.Logger;

/**
 *
 * @author CMS
 */
public class Utility {

    final static String DELIMITER_COMMA = ",";
    final static String DELIMITER_TAB = "\t";

    /**
     *
     * @param list
     * @return
     */
    public static int sum(List<Integer> list) {
        if (list == null || list.size() < 1) {
            return 0;
        }

        int sum = 0;
        for (Integer i : list) {
            sum = sum + i;
        }

        return sum;
    }

    /**
     *
     * @param list
     * @return
     */
    public static String join(List<String> list) {
        return join(list, DELIMITER_COMMA);
    }

    /**
     *
     * @param list
     * @param delimiter
     * @return
     */
    public static String join(List<String> list, String delimiter) {
        if (list == null) {
            return null;
        }
        String del = (delimiter == null ? DELIMITER_COMMA : delimiter);
        StringJoiner joiner = new StringJoiner(del);
        list.forEach((s) -> {
            joiner.add(s);
        });
        return joiner.toString();
    }

    /**
     * Check JVM
     */
    public static void detectJvm() {
        LOG.info("***** Java configuration *****");
        Properties p = System.getProperties();
        Enumeration keys = p.keys();
        while (keys.hasMoreElements()) {
            String key = (String) keys.nextElement();
            String value = (String) p.get(key);
            LOG.log(Level.INFO, "{0}: {1}", new Object[]{key, value});
        }

    }
    private static final Logger LOG = Logger.getLogger(Utility.class.getName());

    /**
     *
     * @param s
     * @param n
     * @return
     */
    public static String adjustLine(String s, int n) {
        String line;
        if (s.length() == n) {
            return s;
        } else {
            if (s.length() > n) {
                line = s.substring(0, n);
            } else {
                line = Utility.padRight(s, n);
            }
        }
        return line;
    }

    /**
     *
     * @param s
     * @param n
     * @return
     */
    public static String padRight(String s, int n) {
        return String.format("%-" + n + "s", s);
    }

    /**
     *
     * @param s
     * @param n
     * @return
     */
    public static String padLeft(String s, int n) {
        return String.format("%" + n + "s", s);
    }

    public static Date processDate(String inpDate) {
        if (inpDate == null) {
            return null;
        }
        String date = inpDate.replaceAll(" ", "x");
        // Reinforce Date checking (only digits allowed)
        if(!isInteger(date)) {
            return null;
        }
        SimpleDateFormat sdf = new SimpleDateFormat(FORMAT_DATE);
        sdf.setLenient(false);
        Date ret = null;
        try {
            ret = sdf.parse(date);
        } catch (ParseException ex) {
            // to prevent NPE
        }
        return ret;
    }

    public static boolean isInteger(String value) {
        try {
            Long.valueOf(value);
            return true;
        } catch (NumberFormatException e) {
            return false;
        }
    }

}
